==> haskell-criterion-measurement-0.1.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-EWvVD7ozesR7jQDklM1iSH
key: criterion-measurement-0.1.1.0-EWvVD7ozesR7jQDklM1iSH
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: abef474e7b8facd8336b556a9f642c4a
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-EWvVD7ozesR7jQDklM1iSH
depends:
    aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ binary-0.8.5.1
    containers-0.5.11.0 deepseq-1.4.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b=c22e056a410eb876f6f97788d58417ce
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.1.1.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-AAZlu7lcoW99eNy8M3s7EB
key: criterion-measurement-0.1.1.0-AAZlu7lcoW99eNy8M3s7EB
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: 02183c0e75fbc4525fe1031d803dc3a5
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-AAZlu7lcoW99eNy8M3s7EB
depends:
    aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ binary-0.8.5.1
    containers-0.5.11.0 deepseq-1.4.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ=2dabf93ee02d5485cbe316a08ea94024
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
